@@ -1,4 +1,3 @@
-import numpy as np
 import tensorflow as tf
 from tensorflow.keras import layers
 
@@ -39,13 +38,12 @@ class EdgeUpdate(GraphLayer):
         super().build(input_shape)
 
         self.gather = nfp.Gather()
-        self.slice1 = nfp.Slice(np.s_[:, :, 1])
-        self.slice0 = nfp.Slice(np.s_[:, :, 0])
         self.concat = nfp.ConcatDense()
 
-    def call(self, inputs, mask=None):
+    def call(self, inputs, mask=None, **kwargs):
         """ Inputs: [atom_state, bond_state, connectivity]
             Outputs: bond_state
+
         """
         if not self.use_global:
             atom_state, bond_state, connectivity = inputs
@@ -54,13 +52,15 @@ class EdgeUpdate(GraphLayer):
             global_state = self.tile([global_state, bond_state])
 
         # Get nodes at start and end of edge
-        source_atom = self.gather([atom_state, self.slice1(connectivity)])
-        target_atom = self.gather([atom_state, self.slice0(connectivity)])
+        source_atom = self.gather([atom_state, connectivity[:, :, 0]])
+        target_atom = self.gather([atom_state, connectivity[:, :, 1]])
 
         if not self.use_global:
-            new_bond_state = self.concat([bond_state, source_atom, target_atom])
+            new_bond_state = self.concat(
+                [bond_state, source_atom, target_atom])
         else:
-            new_bond_state = self.concat([bond_state, source_atom, target_atom, global_state])
+            new_bond_state = self.concat(
+                [bond_state, source_atom, target_atom, global_state])
 
         if self.dropout > 0.:
             new_bond_state = self.dropout_layer(new_bond_state)
@@ -84,8 +84,6 @@ class NodeUpdate(GraphLayer):
         num_features = input_shape[1][-1]
 
         self.gather = nfp.Gather()
-        self.slice0 = nfp.Slice(np.s_[:, :, 0])
-        self.slice1 = nfp.Slice(np.s_[:, :, 1])
 
         self.concat = nfp.ConcatDense()
         self.reduce = nfp.Reduce(reduction='sum')
@@ -93,9 +91,10 @@ class NodeUpdate(GraphLayer):
         self.dense1 = layers.Dense(2 * num_features, activation='relu')
         self.dense2 = layers.Dense(num_features)
 
-    def call(self, inputs, mask=None):
+    def call(self, inputs, mask=None, **kwargs):
         """ Inputs: [atom_state, bond_state, connectivity]
             Outputs: atom_state
+
         """
         if not self.use_global:
             atom_state, bond_state, connectivity = inputs
@@ -103,7 +102,7 @@ class NodeUpdate(GraphLayer):
             atom_state, bond_state, connectivity, global_state = inputs
             global_state = self.tile([global_state, bond_state])
 
-        source_atom = self.gather([atom_state, self.slice1(connectivity)])
+        source_atom = self.gather([atom_state, connectivity[:, :, 1]])
 
         if not self.use_global:
             messages = self.concat([source_atom, bond_state])
@@ -112,10 +111,11 @@ class NodeUpdate(GraphLayer):
 
         if mask is not None:
             # Only works for sum, max
-            messages = tf.where(tf.expand_dims(mask[1], axis=-1),
-                                messages, tf.zeros_like(messages))
+            messages = tf.where(tf.expand_dims(mask[1], axis=-1), messages,
+                                tf.zeros_like(messages))
 
-        new_atom_state = self.reduce([messages, self.slice0(connectivity), atom_state])
+        new_atom_state = self.reduce(
+            [messages, connectivity[:, :, 0], atom_state])
 
         # Dense net after message reduction
         new_atom_state = self.dense1(new_atom_state)
@@ -146,21 +146,20 @@ class GlobalUpdate(GraphLayer):
     def build(self, input_shape):
         super().build(input_shape)
         dense_units = self.units * self.num_heads  # N*H
-        # if self.use_global:
-        #     assert input_shape[-1][-1] == dense_units
         self.query_layer = layers.Dense(self.num_heads, name='query')
         self.value_layer = layers.Dense(dense_units, name='value')
 
     def transpose_scores(self, input_tensor):
         input_shape = tf.shape(input_tensor)
-        output_shape = [input_shape[0], input_shape[1], self.num_heads, self.units]
+        output_shape = [
+            input_shape[0], input_shape[1], self.num_heads, self.units
+        ]
         output_tensor = tf.reshape(input_tensor, output_shape)
         return tf.transpose(a=output_tensor, perm=[0, 2, 1, 3])  # [B,N,S,H]
 
-    def call(self, inputs, mask=None):
+    def call(self, inputs, mask=None, **kwargs):
         if not self.use_global:
             atom_state, bond_state, connectivity = inputs
-            global_state = None
         else:
             atom_state, bond_state, connectivity, global_state = inputs
 
@@ -171,17 +170,18 @@ class GlobalUpdate(GraphLayer):
 
         if mask is not None:
             graph_element_mask = tf.concat([mask[0], mask[1]], axis=1)
-            query = tf.where(
-                tf.expand_dims(graph_element_mask, axis=-1),
-                query,
-                tf.ones_like(query) * query.dtype.min)
+            query = tf.where(tf.expand_dims(graph_element_mask, axis=-1),
+                             query,
+                             tf.ones_like(query) * query.dtype.min)
 
         query = tf.transpose(query, perm=[0, 2, 1])
-        value = self.transpose_scores(self.value_layer(graph_elements))  # [B,N,S,H]
+        value = self.transpose_scores(
+            self.value_layer(graph_elements))  # [B,N,S,H]
 
         attention_probs = tf.nn.softmax(query)
         context = tf.matmul(tf.expand_dims(attention_probs, 2), value)
-        context = tf.reshape(context, [batch_size, self.num_heads * self.units])
+        context = tf.reshape(context,
+                             [batch_size, self.num_heads * self.units])
 
         if self.dropout > 0.:
             context = self.dropout_layer(context)
@@ -190,7 +190,5 @@ class GlobalUpdate(GraphLayer):
 
     def get_config(self):
         config = super(GlobalUpdate, self).get_config()
-        config.update(
-            {"units": self.units,
-             "num_heads": self.num_heads})
+        config.update({"units": self.units, "num_heads": self.num_heads})
         return config
