@@ -15,6 +15,9 @@ logger = logging.getLogger(__name__)
 
 
 class Preprocessor(ABC):
+    def __init__(self, output_dtype: str = 'int32'):
+        self.output_dtype = output_dtype
+
     @abstractmethod
     def create_nx_graph(self, structure: Any, **kwargs) -> nx.DiGraph:
         pass
@@ -49,8 +52,11 @@ class Preprocessor(ABC):
         pass
 
     @staticmethod
-    def get_connectivity(graph: nx.DiGraph) -> Dict[str, np.ndarray]:
-        return {'connectivity': np.asarray(graph.edges)}
+    def get_connectivity(graph: nx.DiGraph, max_num_edges: int) -> Dict[str, np.ndarray]:
+        connectivity = np.zeros((max_num_edges, 2), dtype='int64')
+        if len(graph.edges) > 0:  # Handle odd case with no edges
+            connectivity[:len(graph.edges)] = np.asarray(graph.edges)
+        return {'connectivity': connectivity}
 
     def __call__(self,
                  structure: Any,
@@ -60,28 +66,20 @@ class Preprocessor(ABC):
                  **kwargs) -> Dict[str, np.ndarray]:
         nx_graph = self.create_nx_graph(structure, **kwargs)
 
-        max_num_edges = max(1, len(
-            nx_graph.edges)) if max_num_edges is None else max_num_edges
-        assert len(
-            nx_graph.edges
-        ) <= max_num_edges, "max_num_edges too small for given input"
+        max_num_edges = len(nx_graph.edges) if max_num_edges is None else max_num_edges
+        assert len(nx_graph.edges) <= max_num_edges, "max_num_edges too small for given input"
 
-        max_num_nodes = len(
-            nx_graph.nodes) if max_num_nodes is None else max_num_nodes
-        assert len(
-            nx_graph.nodes
-        ) <= max_num_nodes, "max_num_nodes too small for given input"
+        max_num_nodes = len(nx_graph.nodes) if max_num_nodes is None else max_num_nodes
+        assert len(nx_graph.nodes) <= max_num_nodes, "max_num_nodes too small for given input"
 
         # Make sure that Tokenizer classes are correctly initialized
         for _, tokenizer in getmembers(self, lambda x: type(x) == Tokenizer):
             tokenizer.train = train
 
-        node_features = self.get_node_features(nx_graph.nodes(data=True),
-                                               max_num_nodes)
-        edge_features = self.get_edge_features(nx_graph.edges(data=True),
-                                               max_num_edges)
+        node_features = self.get_node_features(nx_graph.nodes(data=True), max_num_nodes)
+        edge_features = self.get_edge_features(nx_graph.edges(data=True), max_num_edges)
         graph_features = self.get_graph_features(nx_graph.graph)
-        connectivity = self.get_connectivity(nx_graph)
+        connectivity = self.get_connectivity(nx_graph, max_num_edges)
 
         return {
             **node_features,
@@ -119,9 +117,12 @@ class PreprocessorMultiGraph(Preprocessor, ABC):
         pass
 
     @staticmethod
-    def get_connectivity(graph: nx.DiGraph) -> Dict[str, np.ndarray]:
+    def get_connectivity(graph: nx.DiGraph, max_num_edges: int) -> Dict[str, np.ndarray]:
         # Don't include keys in the connectivity matrix
-        return {'connectivity': np.asarray(graph.edges)[:, :2]}
+        connectivity = np.zeros((max_num_edges, 2), dtype='int64')
+        if len(graph.edges) > 0:  # Handle odd case with no edges
+            connectivity[:len(graph.edges)] = np.asarray(graph.edges)[:, :2]
+        return {'connectivity': connectivity}
 
 
 def load_from_json(obj, data):
